==> ulyxex.0.0.4.with-tinyMce.zip: pages/code/admin_link_modify.php <==
<?php
class LinkModify extends Admin {
	public function link_params($id) {
		$req = "SELECT * FROM ".LINKS." WHERE ID=".$id;
		$req = $this->req($req);
		$result = mysql_fetch_assoc($req);
		return $result;
	}
	public function userLinks() {
		$siteDat = $this->home_params();
		$reqLevel2 = 	"SELECT ".LINKS.".ID,".LINKS.".NAME FROM ".LINKS.",".USERLINKS.
						" WHERE ".USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
						USERLINKS.".PAGEID = ".LINKS.".ID ORDER BY ".LINKS.".NAME";
						
		$reqLevel1 = 	"SELECT ID,NAME FROM ".LINKS." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$req = $this->req($reqLevel2);
		} else {
			$req = $this->req($reqLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($req) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$h = New Html();
			$menu = $h->select($elements,"link",$siteDat['PAGEID']).$h->input("submit",null,"GO");
			$result = $h->form("modify ".$menu,"links","post","admin.php?action=modify_link");
			return $result;
		}
	}
	public function update_link($linkId) {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$req = "UPDATE ".LINKS." SET NAME = '".$h->safe($_POST['name'])."',".
									"DESCRIPTION = '".$h->safe($_POST['description'])."',".
									"LINK = '".$h->safe($_POST['linktext'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$linkId;
		$req = $this->req($req);
		$result = $h->h3("link updated !");
		return $result;
	}
	public function data_link($linkId) {
		$h = New Html();
		$reqLevel1 = 	"SELECT ".LINKS.".* FROM ".LINKS." WHERE ID = ".$linkId;
		$reqLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
						USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
						USERLINKS.".PAGEID = ".LINKS.".ID"." AND ".
						LINKS.".ID = ".$linkId;

		if ($_SESSION['level'] > 1) {
			$req = $this->req($reqLevel2);
		} else {
			$req = $this->req($reqLevel1);
		}
		if ($req) {
			$dat = mysql_fetch_assoc($req);
			$content = $h->input("hidden","link",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $h->p("hide ".$h->input("checkbox","hide","on",$params));
			$content .= $h->p("name").$h->p($h->input("text","name",$dat['NAME'],"size=".FIELDWIDTH));
			$content .= $h->p("linktext").$h->p($h->input("text","linktext",$dat['LINK'],"size=".FIELDWIDTH));
			$content .= $h->p("description").$h->p($h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $h->p($h->input("submit","save","update"));
			$result = $h->form($content,"link","post","admin.php?action=modify_link");
			return $result;
		}
	}
}
?>

==> ulyxex.0.0.5.with-tinyMce.zip: pages/code/admin_link_modify.php <==
<?php
class LinkModify extends Admin {
	public function link_params($id) {
		$query = "SELECT * FROM ".LINKS." WHERE ID=".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function userLinks() {
		$siteDat = $this->home_params();
		$queryLevel2 = 	"SELECT ".LINKS.".ID,".LINKS.".NAME FROM ".LINKS.",".USERLINKS.
						" WHERE ".USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
						USERLINKS.".PAGEID = ".LINKS.".ID ORDER BY ".LINKS.".NAME";
						
		$queryLevel1 = 	"SELECT ID,NAME FROM ".LINKS." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$h = New Html();
			$menu = $h->select($elements,"link",$siteDat['PAGEID']).$h->input("submit",null,"GO");
			$result = $h->form("modify ".$menu,"links","post","admin.php?action=modify_link");
			return $result;
		}
	}
	public function update_link($linkId) {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$query = "UPDATE ".LINKS." SET NAME = '".$h->safe($_POST['name'])."',".
									"DESCRIPTION = '".$h->safe($_POST['description'])."',".
									"LINK = '".$h->safe($_POST['linktext'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$linkId;
		$query = $this->q($query);
		$result = $h->h3("link updated !");
		return $result;
	}
	public function data_link($linkId) {
		$h = New Html();
		$queryLevel1 = 	"SELECT ".LINKS.".* FROM ".LINKS." WHERE ID = ".$linkId;
		$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
						USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
						USERLINKS.".PAGEID = ".LINKS.".ID"." AND ".
						LINKS.".ID = ".$linkId;

		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		if ($query) {
			$dat = mysql_fetch_assoc($query);
			$content = $h->input("hidden","link",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $h->p("hide ".$h->input("checkbox","hide","on",$params));
			$content .= $h->p("name").$h->p($h->input("text","name",$dat['NAME'],"size=".FIELDWIDTH));
			$content .= $h->p("linktext").$h->p($h->input("text","linktext",$dat['LINK'],"size=".FIELDWIDTH));
			$content .= $h->p("description").$h->p($h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $h->p($h->input("submit","save","update"));
			$result = $h->form($content,"link","post","admin.php?action=modify_link");
			return $result;
		}
	}
}
?>
